pub struct CcommentCode { /* private fields */ }Trait Implementations
Sourceimpl Alterator for CcommentCode
impl Alterator for CcommentCode
Sourcefn alterate(
node: &Node<'_>,
code: &[u8],
span: bool,
children: Vec<AstNode>,
) -> AstNode
fn alterate( node: &Node<'_>, code: &[u8], span: bool, children: Vec<AstNode>, ) -> AstNode
Creates a new
AST node containing the code associated to the node,
its span, and its children. Read moreSourcefn get_text_span(
node: &Node<'_>,
code: &[u8],
span: bool,
text: bool,
) -> (String, Span)
fn get_text_span( node: &Node<'_>, code: &[u8], span: bool, text: bool, ) -> (String, Span)
Gets the code as text and the span associated to a node.
Sourceimpl Cognitive for CcommentCode
impl Cognitive for CcommentCode
Sourceimpl Cyclomatic for CcommentCode
impl Cyclomatic for CcommentCode
Sourceimpl Halstead for CcommentCode
impl Halstead for CcommentCode
Sourceimpl LanguageInfo for CcommentCode
impl LanguageInfo for CcommentCode
Sourceimpl Loc for CcommentCode
impl Loc for CcommentCode
Sourceimpl Mi for CcommentCode
impl Mi for CcommentCode