pub struct KotlinCode { /* private fields */ }Trait Implementations
Sourceimpl Alterator for KotlinCode
impl Alterator for KotlinCode
Sourcefn alterate(
node: &Node<'_>,
code: &[u8],
span: bool,
children: Vec<AstNode>,
) -> AstNode
fn alterate( node: &Node<'_>, code: &[u8], span: bool, children: Vec<AstNode>, ) -> AstNode
Creates a new
AST node containing the code associated to the node,
its span, and its children. Read moreSourcefn get_text_span(
node: &Node<'_>,
code: &[u8],
span: bool,
text: bool,
) -> (String, Span)
fn get_text_span( node: &Node<'_>, code: &[u8], span: bool, text: bool, ) -> (String, Span)
Gets the code as text and the span associated to a node.
Sourceimpl Cognitive for KotlinCode
impl Cognitive for KotlinCode
Sourceimpl Cyclomatic for KotlinCode
impl Cyclomatic for KotlinCode
Sourceimpl Halstead for KotlinCode
impl Halstead for KotlinCode
Sourceimpl LanguageInfo for KotlinCode
impl LanguageInfo for KotlinCode
Sourceimpl Loc for KotlinCode
impl Loc for KotlinCode
Sourceimpl Mi for KotlinCode
impl Mi for KotlinCode