pub struct MozjsCode { /* private fields */ }Trait Implementations
Sourceimpl Alterator for MozjsCode
impl Alterator for MozjsCode
Sourcefn alterate(
node: &Node<'_>,
code: &[u8],
span: bool,
children: Vec<AstNode>,
) -> AstNode
fn alterate( node: &Node<'_>, code: &[u8], span: bool, children: Vec<AstNode>, ) -> AstNode
Creates a new
AST node containing the code associated to the node,
its span, and its children. Read moreSourcefn get_text_span(
node: &Node<'_>,
code: &[u8],
span: bool,
text: bool,
) -> (String, Span)
fn get_text_span( node: &Node<'_>, code: &[u8], span: bool, text: bool, ) -> (String, Span)
Gets the code as text and the span associated to a node.
Sourceimpl LanguageInfo for MozjsCode
impl LanguageInfo for MozjsCode