pub struct PreprocCode { /* private fields */ }Trait Implementations
Sourceimpl Alterator for PreprocCode
impl Alterator for PreprocCode
Sourcefn alterate(
node: &Node<'_>,
code: &[u8],
span: bool,
children: Vec<AstNode>,
) -> AstNode
fn alterate( node: &Node<'_>, code: &[u8], span: bool, children: Vec<AstNode>, ) -> AstNode
Creates a new
AST node containing the code associated to the node,
its span, and its children. Read moreSourcefn get_text_span(
node: &Node<'_>,
code: &[u8],
span: bool,
text: bool,
) -> (String, Span)
fn get_text_span( node: &Node<'_>, code: &[u8], span: bool, text: bool, ) -> (String, Span)
Gets the code as text and the span associated to a node.
Sourceimpl Cognitive for PreprocCode
impl Cognitive for PreprocCode
Sourceimpl Cyclomatic for PreprocCode
impl Cyclomatic for PreprocCode
Sourceimpl Halstead for PreprocCode
impl Halstead for PreprocCode
Sourceimpl LanguageInfo for PreprocCode
impl LanguageInfo for PreprocCode
Sourceimpl Loc for PreprocCode
impl Loc for PreprocCode
Sourceimpl Mi for PreprocCode
impl Mi for PreprocCode