pub struct PythonCode { /* private fields */ }Trait Implementations
Sourceimpl Alterator for PythonCode
impl Alterator for PythonCode
Sourcefn alterate(
node: &Node<'_>,
code: &[u8],
span: bool,
children: Vec<AstNode>,
) -> AstNode
fn alterate( node: &Node<'_>, code: &[u8], span: bool, children: Vec<AstNode>, ) -> AstNode
Creates a new
AST node containing the code associated to the node,
its span, and its children. Read moreSourcefn get_text_span(
node: &Node<'_>,
code: &[u8],
span: bool,
text: bool,
) -> (String, Span)
fn get_text_span( node: &Node<'_>, code: &[u8], span: bool, text: bool, ) -> (String, Span)
Gets the code as text and the span associated to a node.
Sourceimpl Cognitive for PythonCode
impl Cognitive for PythonCode
Sourceimpl Cyclomatic for PythonCode
impl Cyclomatic for PythonCode
Sourceimpl Halstead for PythonCode
impl Halstead for PythonCode
Sourceimpl LanguageInfo for PythonCode
impl LanguageInfo for PythonCode
Sourceimpl Loc for PythonCode
impl Loc for PythonCode
Sourceimpl Mi for PythonCode
impl Mi for PythonCode