pub struct TypescriptCode { /* private fields */ }Trait Implementations
Sourceimpl Alterator for TypescriptCode
impl Alterator for TypescriptCode
Sourcefn alterate(
node: &Node<'_>,
code: &[u8],
span: bool,
children: Vec<AstNode>,
) -> AstNode
fn alterate( node: &Node<'_>, code: &[u8], span: bool, children: Vec<AstNode>, ) -> AstNode
Creates a new
AST node containing the code associated to the node,
its span, and its children. Read moreSourcefn get_text_span(
node: &Node<'_>,
code: &[u8],
span: bool,
text: bool,
) -> (String, Span)
fn get_text_span( node: &Node<'_>, code: &[u8], span: bool, text: bool, ) -> (String, Span)
Gets the code as text and the span associated to a node.
Sourceimpl Cognitive for TypescriptCode
impl Cognitive for TypescriptCode
Sourceimpl Cyclomatic for TypescriptCode
impl Cyclomatic for TypescriptCode
Sourceimpl Halstead for TypescriptCode
impl Halstead for TypescriptCode
Sourceimpl LanguageInfo for TypescriptCode
impl LanguageInfo for TypescriptCode
Sourceimpl Loc for TypescriptCode
impl Loc for TypescriptCode
Sourceimpl Mi for TypescriptCode
impl Mi for TypescriptCode